@@ -8,10 +8,10 @@ from pyspark.sql import DataFrame
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
 from spark_pipeline_framework.proxy_generator.python_transformer_helpers import get_python_transformer_from_location, \
     get_python_function_from_location
-from spark_pipeline_framework.transformers.framework_csv_loader import FrameworkCsvLoader
-from spark_pipeline_framework.transformers.framework_mapping_runner import FrameworkMappingLoader
-from spark_pipeline_framework.transformers.framework_sql_transformer import FrameworkSqlTransformer
-from spark_pipeline_framework.transformers.framework_transformer import FrameworkTransformer
+from spark_pipeline_framework.transformers.framework_csv_loader.v1.framework_csv_loader import FrameworkCsvLoader
+from spark_pipeline_framework.transformers.framework_mapping_runner.v1.framework_mapping_runner import FrameworkMappingLoader
+from spark_pipeline_framework.transformers.framework_sql_transformer.v1.framework_sql_transformer import FrameworkSqlTransformer
+from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import FrameworkTransformer
 
 
 class ProxyBase(FrameworkTransformer):
